% -------------------------------------------------------------------------
% Script constructs dataset Pooling paper
% open sav file without spss: http://pspp.benpfaff.org/
% -------------------------------------------------------------------------
% load data
% -------------------------------------------------------------------------
clear;
load('CVO2015_161123_V.mat');
Rresp     = RESPNR;
Rdest     = V420S;
Rdura     = V402;
monthdays = cumsum([0 31 28 31 30 31 30 31 31 30 31 30]);
Rdate     = V110+monthdays(V111)'+(V112-1)*365;
% -------------------------------------------------------------------------
% set variable of interest
% -------------------------------------------------------------------------
Hlength  = Rdura>7;
Hdest    = Rdest(Hlength,:);
Hresp    = Rresp(Hlength,:);
% -------------------------------------------------------------------------
% set explanatory variables
% -------------------------------------------------------------------------
clearvars -except Hresp Hdest Hprev Rdest Rdura Hlength;
load('CVO2015_161123_P.mat');
Presp      = V001;
incgroup   = log([4600 6300 8000 9100 10800 12500 14300 15400 17100 20000 23400 26200 32500 38800 51300 65000 77500 103800 129400 155100 181300 206400 232600 258900 284500 310700 350000 1 1]);
Pinc       = (incgroup(V006)');
Pincnotr   = ((V006==28) + (V006==29))==1;
Pretired   = V016==2;
Pstudent   = V016==7;
Ppropmov   = ((V020==1)+(V021==1)+(V022==1)+(V023==1))>0;
Ppropfix   = ((V030==1)+(V031==1)+(V032==1)+(V033==1)+(V034==1)+(V035==1)+(V036==1))>0;
Psoclass   = [V333==2 V333==3 V333==4 V333==5];
Pfamilyc   = [V320==1 V320==2 V320==3 V320==4 V320==5 V320==6 V320==7 V320==8 V320==9 V320==10];
Xdata      = [Pinc Pincnotr Pretired Pstudent Ppropmov Ppropfix Psoclass Pfamilyc];
[y, Xp]    = createVars(Hdest,Xdata,Hresp,Presp);
HL = Rdura(Hlength);
clearvars -except y Xp Hdest HL Rdura Rdest
% -------------------------------------------------------------------------
% 
% -------------------------------------------------------------------------
% cleaning Y destinations
dum = dummyvar(Hdest);
Ydestdum = [dum(:,[13 1:2]) sum(dum(:,3:4),2) dum(:,[5 6]) sum(dum(:,7:9),2)...
dum(:,[10:12 14:19 21 22 23]) sum(dum(:,[20 24 25]),2) dum(:,26) sum(dum(:,[27 28]),2)...
dum(:,[29 30 32 33]) sum(dum(:,[31 35]),2) dum(:,[36 37 38]) sum(dum(:,[40 41]),2)...
dum(:,42) sum(dum(:,[43 44]),2) sum(dum(:,[45 46]),2) dum(:,47:48) sum(dum(:,[34 49]),2) ...
sum(dum(:,[50 51]),2) sum(dum(:,52:54),2) dum(:,55:58) sum(dum(:,[59 60]),2) dum(:,62) sum(dum(:,[63 64]),2) dum(:,65:69) ...
sum(dum(:,[70 71]),2) dum(:,72:74) sum(dum(:,[75 76]),2)];
% delete observations for which we have too little observations
delobs = (Hdest==61) + (Hdest==77) + (Hdest==79);
Ydestdum(delobs==1,:)=[];
delcat = sum(Ydestdum)==0;
Ydestdum(:,delcat)=[];
[Ydest,~] = find(Ydestdum');
X = Xp(delobs==0,:);
HL = HL(delobs==0,:);
% -------------------------------------------------------------------------
% Ydest for all observations in data set for the spells
dum = dummyvar(Rdest);
Ydestdum = [dum(:,[13 1:2]) sum(dum(:,3:4),2) dum(:,[5 6]) sum(dum(:,7:9),2)...
dum(:,[10:12 14:19 21 22 23]) sum(dum(:,[20 24 25]),2) dum(:,26) sum(dum(:,[27 28]),2)...
dum(:,[29 30 32 33]) sum(dum(:,[31 35]),2) dum(:,[36 37 38]) sum(dum(:,[40 41]),2)...
dum(:,42) sum(dum(:,[43 44]),2) sum(dum(:,[45 46]),2) dum(:,47:48) sum(dum(:,[34 49]),2) ...
sum(dum(:,[50 51]),2) sum(dum(:,52:54),2) dum(:,55:58) sum(dum(:,[59 60]),2) dum(:,62) sum(dum(:,[63 64]),2) dum(:,65:69) ...
sum(dum(:,[70 71]),2) dum(:,72:74) sum(dum(:,[75 76]),2)];
Ydestdum(:,delcat)=[];
% -------------------------------------------------------------------------
% cleaning worldmap
catnames = {'France','Iceland','Norway',3,'Denmark','Ireland','United Kingdom',10,...
 'Belgium','Luxembourg','Germany','Switzerland','Austria',17,...
 'Poland','Czech Republic','Hungary','Romania','Bulgaria',25,...
 'Portugal',27,'Italy','Malta','Croatia','Greece',35,...
 'Morocco','Tunisia','Egypt',41,42,44,46,...
 'Cyprus','Israel','Turkey',51,54,'China',56,...
 'Indonesia','Thailand','Southeastern Asia',0,'Australia',0,0,...
 'Canada','United States','Netherlands Antilles',71,'Mexico',...
 73,'Venezuela',76};
catnames(:,delcat)=[];

catnamesr = {'France','Iceland','Norway','Sweden/Finland','Denmark','Ireland','United Kingdom',0,...
 'Belgium','Luxembourg','Germany','Switzerland','Austria',0,...
 'Poland','Czech Republic','Hungary','Romania','Bulgaria','Eastern Europe',...
 'Portugal','Spain','Italy','Malta','Croatia','Greece','Southern Europe',...
 'Morocco','Tunisia','Egypt','Eastern Africa',0,'West Africa','Southern Africa',...
 'Cyprus','Israel','Turkey','Western Asia','Southern Asia','China','Eastern Asia',...
 'Indonesia','Thailand','Southeastern Asia',62,'Australia',65,66,...
 'Canada','United States','Netherlands Antilles','Caribbean','Mexico',...
 'Central America','Venezuela','Southern America'};
catnamesr(:,delcat)=[];
%set remaining categories
rc(1).cats  = catnames;
rc(1).catsr  = catnamesr;
rc(1).group = [3 10 17 25 27 35 39 41 42 44 46 51 54 56 60 61 62 63 65 66 71 73 76];
rc(1).index = [21 1  2  3 22 4  5  6  7  8  9  10 11 12 13 14 15 23 16 17 18 19 20];
rc(1).names={'Estonia','Faroe Islands','Guernsey','Isle of Man','Jersey','Latvia','Lithuania','Svalbard','land Islands'};
rc(2).names={'Monaco','Liechtenstein'};
rc(3).names={'Belarus','Republic of Moldova','Ukraine','Slovakia','Russia'};
rc(4).names={'Slovenia','Albania','Bosnia and Herzegovina','Gibraltar','Holy See (Vatican City)','Montenegro','San Marino','Serbia','The former Yugoslav Republic of Macedonia'};
rc(5).names={'Tunesia','Algeria','Libyan Arab Jamahiriya','Sudan','Western Sahara'};
rc(6).names={'Kenya','Burundi','Comoros','Djibouti','Eritrea','Ethiopia','Madagascar','Malawi','Mauritius','Mayotte','Mozambique','Reunion','Rwanda','Seychelles','Somalia','Uganda','United Republic of Tanzania','Zambia','Zimbabwe'};
rc(7).names={'Angola','Cameroon','Central African Republic','Chad','Congo','Democratic Republic of the Congo','Equatorial Guinea','Sao Tome and Principe'};
rc(8).names={'Gambia','Benin','Burkina Faso','Cape Verde','Cote dIvoire','Ghana','Guinea','Guinea-Bissau','Liberia','Mali','Mauritania','Niger','Nigeria','Saint Helena','Senegal','Sierra Leone','Togo'};
rc(9).names={'South Africa','Botswana','Lesotho','Namibia','Swaziland'};
rc(10).names={'Jordan','Armenia','Azerbaijan','Bahrain','Georgia','Iraq','Kuwait','Lebanon','Oman','Palestine','Qatar','Saudi Arabia','Syrian Arab Republic','United Arab Emirates','Yemen'};
rc(11).names={'Afghanistan','Bangladesh','Bhutan','Iran (Islamic Republic of)','Maldives','Nepal','Pakistan','India','Sri Lanka'};
rc(12).names={'Hong Kong','Japan','Korea, Democratic Peoples Republic of','Korea, Republic of','Macau','Mongolia'};
rc(13).names={'Brunei Darussalam','Burma','Cambodia','Lao Peoples Democratic Republic','Philippines','Singapore','Timor-Leste','Viet Nam','Malaysia'};
rc(14).names={'Kazakhstan','Kyrgyzstan','Tajikistan','Turkmenistan','Uzbekistan'};
rc(15).names={'Fiji','New Caledonia','Papua New Guinea','Solomon Islands','Vanuatu'};
rc(16).names={'Guam','Kiribati','Marshall Islands','Micronesia, Federated States of','Nauru','Northern Mariana Islands','Palau'};
rc(17).names={'American Samoa','Cook Islands','French Polynesia','Niue','Pitcairn Islands','Samoa','Tokelau','Tonga','Tuvalu','Wallis and Futuna Islands'};
rc(18).names={'Dominican Republic','Anguilla','Antigua and Barbuda','Aruba','Bahamas','Barbados','British Virgin Islands','Cayman Islands','Cuba','Dominica','Grenada','Guadeloupe','Haiti','Jamaica','Martinique','Montserrat','Puerto Rico','Saint Barthelemy','Saint Kitts and Nevis','Saint Lucia','Saint Martin','Saint Vincent and the Grenadines','Trinidad and Tobago','Turks and Caicos Islands','United States Virgin Islands'};
rc(19).names={'Belize','Costa Rica','El Salvador','Guatemala','Honduras','Mexico','Nicaragua','Panama'};
rc(20).names={'Brazil','Argentina','Bolivia','Chile','Colombia','Ecuador','Falkland Islands (Malvinas)','French Guiana','Guyana','Paraguay','Peru','Suriname','Uruguay'};
rc(21).names={'Sweden','Finland'};
rc(22).names={'Spain','Andorra'};
rc(23).names={'Australia','New Zealand'};


rc(1).dnames = {'single <35','single >=35','kids 0-5','kids 6-12','kids 13-17','kids 0-5, 6-12',...
    'kids 0-5, 13-17','kids 6-12, 13-17','kids 0-5, 6-12, 13-17','hh>1, head<35','hh>1, head>=35'};
rc(1).cnames = {'no income','retired','student','moving accomodation','fixed accomodation','social class B1',...
    'social class B2','social class C','social class D'};
% -------------------------------------------------------------------------
% save data
% -------------------------------------------------------------------------
clearvars -except Ydest X rc Ydestdum HL Rdura
save('DatasetNew');
% -------------------------------------------------------------------------