function R = GRtest(theta)
% Gelman-Rubin test
% R should be one
% IN:  theta=nSamples*nParams*nChains
% OUT: R=nParams
[nSamples,nParams,nChains] = size(theta);
R = zeros(nParams,1);
for p=1:nParams
    thetap   = squeeze(theta(:,p,:));
    postmean = mean(thetap)';
    postvar  = var(thetap)';
    chmean   = mean(postmean);
    B        = (nSamples/(nChains-1))*sum((postmean-chmean).^2);
    W        = mean(postvar);
    V        = (nSamples/(nSamples-1))*W+((nChains+1)/(nChains*nSamples))*B;
    R(p)     = sqrt(V/W);
end

% report  Max GelmanRubin Rc
% Rc values greater than 1.2 for any of the model parameters should indicate nonconvergence. 
% In practice, a more stringent rule of Rc < 1.1 is often used to declare convergence.
end
