% -------------------------------------------------------------------------
clear; close all;
fn = 'ResultsCluster\';
% -------------------------------------------------------------------------
% CONVERGENCE STATISTICS TWO-WAY
% 1. Gelman and Rubin (1992) R-hat statistic
MNL2s1       = load([fn 'AppC11sett1seed1.mat'],'alphGibbs','betaGibbs');
theta        = [MNL2s1.alphGibbs;reshape(MNL2s1.betaGibbs,19*48,10000)]';
MNL2s        = load([fn 'AppC11sett1seed2.mat'],'alphGibbs','betaGibbs');
theta(:,:,2) = [MNL2s.alphGibbs;reshape(MNL2s.betaGibbs,19*48,10000)]';
MNL3s        = load([fn 'AppC11sett1seed3.mat'],'alphGibbs','betaGibbs');
theta(:,:,3) = [MNL3s.alphGibbs;reshape(MNL3s.betaGibbs,19*48,10000)]';
R            = GRtest(theta); max(R)
% 2. Convergence test Geweke (1992)
% 3. Inefficiency factor
conv         = load([fn 'AppC11sett1seed1.mat'],'cd_theta','if_theta');
mean(conv.cd_theta)
% 4. autocorrelation plot
ntheta = size(theta,2);
y=zeros(ntheta,1001); 
for i=1:ntheta
    y(i,:)=autocorr(theta(:,i,1),'NumLags',1000); 
end
h = figure; 
plot(y','Color',[0 0 0 0.05]); hold on; yline(0,'Color',[1 1 1]);
xlim([0 1000]);
xlabel('lag');
ylabel('autocorrelation');
%title('autocorrelation functions of all model parameters');
set(h,'Position',[20 60 600 300]);
name = 'acTheta';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% 5. effective sample size
nSamples = size(theta,1);
ess = nSamples./conv.if_theta;
min(ess)
h=figure; 
histogram(conv.if_theta,'FaceColor','k','Normalization','probability');
xlim([0 100]);
xlabel('inefficiency factor');
ylabel('probability');
%title('inefficiency factors of all model parameters');
set(h,'Position',[20 60 600 300]);
name = 'ifTheta';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% Model evaluation
Models = [[1 1];[1 0];[0 1];[0 0]];
Table1 = zeros(4);
for m=1:4
    load([fn 'AppC' strrep(num2str(Models(m,:)),' ','')  'sett1seed1.mat']);
    Table1(:,m)=[lsin;hrin;lsout;hrout];
end
% -------------------------------------------------------------------------
% descriptive statistics holiday destination choices by household categories
load('DatasetNold_date.mat');
load([fn 'AppC11sett1seed1.mat']);
% 
X = [X;Xout];
Y = [Y; Yout];
Xd    = [1-sum(X(:,10:end),2) X(:,10:end) ];
permd = [2 11 3 1 6 8 5 4 7 9 10];
%
N    = length(Y);
sumY = sort(sum(Y),'descend');
CT=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(1:2)),2).*sum(X(:,7:9),2))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C1=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(3:5)),2).*sum(X(:,7:9),2))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C2=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(6:11)),2).*sum(X(:,7:9),2))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C3=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(1:2)),2).*(sum(X(:,7:9),2)==0))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C4=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(3:5)),2).*(sum(X(:,7:9),2)==0))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C5=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];

select_hh =(sum(Xd(:,permd(6:11)),2).*(sum(X(:,7:9),2)==0))==1;
N = sum(select_hh);
sumY = sort(sum(Y(select_hh,:)),'descend');
C6=[sum((cumsum(sumY)>=0.5*N)==0)+1;sum((cumsum(sumY)>=0.8*N)==0)+1;...
sum((cumsum(sumY)>=0.9*N)==0)+1;sum((cumsum(sumY)>=1.0*N)==0)+1;N];
Table2 = [ C4 C5 C6 C1 C2 C3 CT];
% -------------------------------------------------------------------------
load('DatasetNold_date.mat','rc');
load([fn 'AppC11sett1seed1.mat'],'pc','pd','cindGibbs','dindGibbs',...
    'X','Y','Xout','Yout'); %md2 -> md1N3926
MNL2 = load([fn 'AppC11sett1seed1.mat'],'Cnum','Dnum'); 
MNLJ = load([fn 'AppC10sett1seed1.mat'],'Cnum'); 
MNLK = load([fn 'AppC01sett1seed1.mat'],'Dnum'); 
Lc = length(pc);
Ld = length(pd);
% -------------------------------------------------------------------------
% distribution number of clusters
pc_hat2 = zeros(Lc,1);
pc_hatJ = zeros(Lc,1);
for l=1:Lc
    pc_hat2(l) = mean(MNL2.Cnum==l);
    pc_hatJ(l) = mean(MNLJ.Cnum==l);
end
pd_hat2 = zeros(Ld,1);
pd_hatK = zeros(Ld,1);
for l=1:Ld
    pd_hat2(l) = mean(MNL2.Dnum==l);
    pd_hatK(l) = mean(MNLK.Dnum==l);
end
% -------------------------------------------------------------------------
% Figure: distribution number of unique parameters
h=figure;
lw = 2;
subplot(1,2,1); % cluster J
plot(1:Lc,100*pc,'-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat2,'k-','LineWidth',lw); hold on;
plot(1:Lc,100*pc_hatJ,'k:','LineWidth',lw); 
xlim([1 Lc]);
xlabel('number of clusters');
ylabel('probability');
title('holiday destinations');
subplot(1,2,2); % cluster K
plot(1:Ld,100*pd,'-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat2,'k-','LineWidth',lw); hold on;
plot(1:Ld,100*pd_hatK,'k:','LineWidth',lw); 
xlim([1 Ld]);
% set(gca,'XTick', 1:1:d1,'YTick',0.1:0.1:1.0,'FontSize',fs);
xlabel('number of clusters');
ylabel('probability');
title('household types');
legend('prior','two-way','one-way');
set(h,'Position',[20 60 800 300]);
name = 'numClusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% pairwise clustering matrix
J = size(cindGibbs,1)+1;
nSamples = size(cindGibbs,2);
Kd = size(dindGibbs,1);
memberj     = zeros(J);
memberc     = zeros(nSamples,J*J);
memberd     = zeros(Kd+1);
cind1Gibbs  = [ones(1,nSamples);cindGibbs];
dind1Gibbs  = [ones(1,nSamples);dindGibbs];
startmember = tic;
for g=1:nSamples
    mcg = zeros(J);
    for i=1:J
        for j=1:J
        mcg(i,j) = mcg(i,j)+ (cind1Gibbs(i,g)==cind1Gibbs(j,g));
        end
    end
    memberj = memberj+mcg/nSamples;
    memberc(g,:) = mcg(:)';
    for i=1:Kd+1
        for j=1:Kd+1
        memberd(i,j) = memberd(i,j)+ (dind1Gibbs(i,g)==dind1Gibbs(j,g))/nSamples;
        end
    end
end
memberTime = toc(startmember);
% -------------------------------------------------------------------------
% figure explanatory clustering
cmap = flipud(gray);
permd = [2 11 3 1 6 8 5 4  7  9 10 ];%[1 11 2 3 8 6 4 5 7 9 10];
mdplot = memberd(permd,permd); mdplot(1,:)=mdplot(1,:)+0.0001;
h=figure; imagesc(mdplot); 
colormap(cmap); colorbar('Ticks',0:0.1:1); 
ax1=gca;
names1 = [rc(1).dnames(end) rc(1).dnames(1:end-1)];
set(ax1,'xtick',1:Kd+1,'xticklabel',names1(permd),'Ticklength', [0 0]); %
set(ax1,'ytick',1:Kd+1,'yticklabel',names1(permd),'Ticklength', [0 0])
xtickangle(45);
set(h,'Position',[20 60 500 400]);
name = 'expClusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% figure outcome clustering
cmap = flipud(gray);
permc = [34;25;24;11;1;8;9;20;10;5;12;23;21;14;7;3;18;4;15;17;40;27;49;47;46;42;41;38;35;33;31;29;22;48;26;2;32;45;44;43;39;37;36;28;19;16;13;6;30];
h=figure; A=memberj(permc,permc); A(1,:)=A(1,:)+0.0001; imagesc(A); 
colormap(cmap); colorbar('Ticks',0:0.1:1); 
ax1=gca;
names2 = rc(1).catsr;
set(ax1,'xtick',1:J,'xticklabel',names2(permc),'Ticklength', [0 0]); %
set(ax1,'ytick',1:J,'yticklabel',names2(permc),'Ticklength', [0 0]);
xtickangle(45);
set(h,'Position',[20 60 500*2 400*2]);
name = 'outClusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% figure 5: posterior parameter distributions
indj      = 6;%43; %+1 because france=1 not included
indk      = [1 2 13];%[1 2 14]; %[12 16 20];%
MNL2 = load([fn 'AppC11sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNL2 = [MNL2.alphGibbs(indj,:);squeeze(MNL2.betaGibbs(:,indj,:))];
MNLJ = load([fn 'AppC10sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNLJ = [MNLJ.alphGibbs(indj,:);squeeze(MNLJ.betaGibbs(:,indj,:))];
MNLK = load([fn 'AppC01sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNLK = [MNLK.alphGibbs(indj,:);squeeze(MNLK.betaGibbs(:,indj,:))];
MNLN = load([fn 'AppC00sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNLN = [MNLN.alphGibbs(indj,:);squeeze(MNLN.betaGibbs(:,indj,:))];

Tablesd   = zeros(4,3);
cnames    = ['intercept' 'income' rc(1).cnames([1 3:9]) rc(1).dnames(1:10)];
%titletext = {'Intercept','Control: income','Household: kids 0-5'};
%titletext = {'Intercept','Control: income','Household: kids 0-5'};

x         = -4:0.001:4;
fs        = 12;
h         = figure; 
ls = {'-','--',':','-'};
lc = [[0 0 0];[0 0 0];[0 0 0];[.6 .6 .6]];
for i=1:length(indk)
h2     = subplot(1,length(indk),i);
pp2    = get(h2, 'pos');
pp2(3) = pp2(3) + 0.02;
set(h2, 'pos', pp2);

A =[MNL2(indk(i),:);MNLJ(indk(i),:);MNLK(indk(i),:);MNLN(indk(i),:)];
ylimm=0;
for j=1:4
    pd   = fitdist(A(j,:)','Kernel');
    y    = pdf(pd,x);
    plot(x(y>0.01),y(y>0.01),ls{j},'Color',lc(j,:),'LineWidth',2); hold on;
    Tablesd(j,i) = std(A(j,:));
    if max(y)>ylimm
        ylimm=max(y);
    end
end
ylim([0 ylimm*1.1]);

title(cnames(indk(i)),'FontSize',12);
if i==1
    ylabel(rc(1).cats(indj+1),'FontSize',12);
end
%Tablesd(:,i) = [std(MNPI.beta(:,indp));std(DPM2.beta(:,indp));std(DPMJ.beta(:,indp));std(DPMK.beta(:,indp)) ];
set(gca,'YTick',[],'FontSize',fs);
if i==1
legend({'two-way','holiday','household','standard'},'FontSize',12);
end
hold off;
end
set(h, 'Position', [20 60 1100 300]);
name = 'paramdens';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% Probabilities destinations for different household categories
MNL2  = load([fn 'AppC11sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNLN  = load([fn 'AppC00sett1seed1.mat'],'alphGibbs','betaGibbs'); 
% X=[income, 8 control dummies, 10 household dummies]
prob2 = zeros(Kd+1,J,nSamples);
probN = zeros(Kd+1,J,nSamples);
probC = zeros(Kd+1,J,nSamples);
Xi    = [[0 0 0 0 0 0 0 0 0] zeros(1,Kd)];
XiC   = [[0 0 0 0 1 0 0 0 0] zeros(1,Kd)];
Kw    = size(X,2)-Kd;
for k=1:Kd+1
    % calculate probabilities household k
    Xik  = Xi;
    XiCk = XiC;
    if k>1
        Xik(Kw+k-1)  = 1;
        XiCk(Kw+k-1) = 1;
    end
    expXB2 = ones(1,J);
    expXBN = ones(1,J);
    expXBC = ones(1,J);
    for g=1:nSamples
        expXB2(2:J)  = exp(MNL2.alphGibbs(:,g)'+Xik*MNL2.betaGibbs(:,:,g));
        prob2(permd==k,:,g) = expXB2(permc)/sum(expXB2(permc),2);
        expXBN(2:J)  = exp(MNLN.alphGibbs(:,g)'+Xik*MNLN.betaGibbs(:,:,g));
        probN(permd==k,:,g) = expXBN(permc)/sum(expXBN(permc),2);
        expXBC(2:J)  = exp(MNL2.alphGibbs(:,g)'+XiCk*MNL2.betaGibbs(:,:,g));
        probC(permd==k,:,g) = expXBC(permc)/sum(expXBC(permc),2);
    end
end
% -------------------------------------------------------------------------
% odds ratios
selectJ = [1 3 38 39];%
selectK = [1 2 8 9];
ORindex = nchoosek(selectJ,2);
OR2     = zeros(length(selectK),length(selectJ));
ORN     = zeros(length(selectK),length(selectJ));
ORC     = zeros(length(selectK),length(selectJ));
namesJ  = names2(permc);
ORnames = cell(6,1); 
for i=1:size(ORindex,1)
    or2 = prob2(selectK,ORindex(i,1),:)./prob2(selectK,ORindex(i,2),:);
    orN = probN(selectK,ORindex(i,1),:)./probN(selectK,ORindex(i,2),:);
    orC = probC(selectK,ORindex(i,1),:)./probC(selectK,ORindex(i,2),:);
    OR2(:,i) = mean(squeeze(or2),2);
    ORN(:,i) = mean(squeeze(orN),2);
    ORC(:,i) = mean(squeeze(orC),2);
    ORnames{i} = ['$\frac{P(y_i=\mathrm{' namesJ{ORindex(i,1)} '})}{P(y_i=\mathrm{' namesJ{ORindex(i,2)} '})}$'];
end
% -------------------------------------------------------------------------
barnames = names1(permd);
h=figure; 
b=bar(OR2'); 
xticklabels(ORnames); 
ylim([0 6.5]); yticks(0:6);
yline(1,'Color','k','LineWidth',1.5);
%title('MNP2');
set(gca,'TickLabelInterpreter','latex','Fontsize',14);
legend(barnames(selectK),'Fontsize',10); 
ylabel('odds ratio','Fontsize',12);
b(1).FaceColor = [1 1 1];
b(2).FaceColor = [0.8 0.8 0.8];
b(3).FaceColor = [0.4 0.4 0.4];
b(4).FaceColor = [0 0 0];
set(h, 'Position', [20 60 1100 300]);
name = 'ORmnp2';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
h=figure; 
b=bar(ORN'); 
xticklabels(ORnames); 
ylim([0 7.5]); yticks(0:7);
yline(1,'Color','k','LineWidth',1.5);
%title('MNP2');
set(gca,'TickLabelInterpreter','latex','Fontsize',14);
legend(barnames(selectK),'Fontsize',10); 
ylabel('odds ratio','Fontsize',12);
b(1).FaceColor = [1 1 1];
b(2).FaceColor = [0.8 0.8 0.8];
b(3).FaceColor = [0.4 0.4 0.4];
b(4).FaceColor = [0 0 0];
set(h, 'Position', [20 60 1100 300]);
name = 'ORmnpn';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
load([fn 'AppC10sett1seed1.mat'],'pc','pd','cindGibbs','dindGibbs','X','Y','Xout','Yout');
% pairwise clustering matrix
J = size(cindGibbs,1)+1;
nSamples = size(cindGibbs,2);
Kd = size(dindGibbs,1);
memberj     = zeros(J);
memberc     = zeros(nSamples,J*J);
memberd     = zeros(Kd+1);
cind1Gibbs  = [ones(1,nSamples);cindGibbs];
dind1Gibbs  = [ones(1,nSamples);dindGibbs];
startmember = tic;
for g=1:nSamples
    mcg = zeros(J);
    for i=1:J
        for j=1:J
        mcg(i,j) = mcg(i,j)+ (cind1Gibbs(i,g)==cind1Gibbs(j,g));
        end
    end
    memberj = memberj+mcg/nSamples;
    memberc(g,:) = mcg(:)';
    for i=1:Kd+1
        for j=1:Kd+1
        memberd(i,j) = memberd(i,j)+ (dind1Gibbs(i,g)==dind1Gibbs(j,g))/nSamples;
        end
    end
end
memberTime = toc(startmember);
% figure outcome clustering
load('DatasetNold_date.mat','rc');
cmap = flipud(gray);
% permc = 1:49;
% aa = [34 24 20 7 21  12 14 8 10 5];
permc = [34;25;24;11;1;8;9;20;10;5;12;23;21;14;7;3;18;4;15;17;40;27;49;47;46;42;41;38;35;33;31;29;22;48;26;2;32;45;44;43;39;37;36;28;19;16;13;6;30];
h=figure; A=memberj(permc,permc); A(1,:)=A(1,:)+0.0001; imagesc(A); 
colormap(cmap); colorbar('Ticks',0:0.1:1); 
ax1=gca;
names2 = rc(1).catsr;
set(ax1,'xtick',1:J,'xticklabel',names2(permc),'Ticklength', [0 0]); %
set(ax1,'ytick',1:J,'yticklabel',names2(permc),'Ticklength', [0 0]);
xtickangle(45);
set(h,'Position',[20 60 500*2 400*2]);
name = 'out1Clusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
% -------------------------------------------------------------------------
permd = [2 11 3 1 6 8 5 4  7  9 10 ];%[1 11 2 3 8 6 4 5 7 9 10];
permc=[34;25;24;11;1;8;9;20;10;5;12;23;21;14;7;3;18;4;15;17;40;27;49;47;46;42;41;38;35;33;31;29;22;48;26;2;32;45;44;43;39;37;36;28;19;16;13;6;30];
names1 = [rc(1).dnames(end) rc(1).dnames(1:end-1)];
names2 = rc(1).catsr;
% Probabilities destinations for different household categories
MNL2  = load([fn 'AppC10sett1seed1.mat'],'alphGibbs','betaGibbs'); 
MNLN  = load([fn 'AppC00sett1seed1.mat'],'alphGibbs','betaGibbs'); 
% X=[income, 8 control dummies, 10 household dummies]
prob2 = zeros(Kd+1,J,nSamples);
probN = zeros(Kd+1,J,nSamples);
probC = zeros(Kd+1,J,nSamples);
Xi    = [[0 0 0 0 0 0 0 0 0] zeros(1,Kd)];
XiC   = [[0 0 0 0 1 0 0 0 0] zeros(1,Kd)];
Kw    = size(X,2)-Kd;
for k=1:Kd+1
    % calculate probabilities household k
    Xik  = Xi;
    XiCk = XiC;
    if k>1
        Xik(Kw+k-1)  = 1;
        XiCk(Kw+k-1) = 1;
    end
    expXB2 = ones(1,J);
    expXBN = ones(1,J);
    expXBC = ones(1,J);
    for g=1:nSamples
        expXB2(2:J)  = exp(MNL2.alphGibbs(:,g)'+Xik*MNL2.betaGibbs(:,:,g));
        prob2(permd==k,:,g) = expXB2(permc)/sum(expXB2(permc),2);
        expXBN(2:J)  = exp(MNLN.alphGibbs(:,g)'+Xik*MNLN.betaGibbs(:,:,g));
        probN(permd==k,:,g) = expXBN(permc)/sum(expXBN(permc),2);
        expXBC(2:J)  = exp(MNL2.alphGibbs(:,g)'+XiCk*MNL2.betaGibbs(:,:,g));
        probC(permd==k,:,g) = expXBC(permc)/sum(expXBC(permc),2);
    end
end
% odds ratios
selectJ = [1 3 38 39];%
selectK = [1 2 8 9];
ORindex = nchoosek(selectJ,2);
OR2     = zeros(length(selectK),length(selectJ));
ORN     = zeros(length(selectK),length(selectJ));
ORC     = zeros(length(selectK),length(selectJ));
namesJ  = names2(permc);
ORnames = cell(6,1); 
for i=1:size(ORindex,1)
    or2 = prob2(selectK,ORindex(i,1),:)./prob2(selectK,ORindex(i,2),:);
    orN = probN(selectK,ORindex(i,1),:)./probN(selectK,ORindex(i,2),:);
    orC = probC(selectK,ORindex(i,1),:)./probC(selectK,ORindex(i,2),:);
    OR2(:,i) = mean(squeeze(or2),2);
    ORN(:,i) = mean(squeeze(orN),2);
    ORC(:,i) = mean(squeeze(orC),2);
    ORnames{i} = ['$\frac{P(y_i=\mathrm{' namesJ{ORindex(i,1)} '})}{P(y_i=\mathrm{' namesJ{ORindex(i,2)} '})}$'];
end
barnames = names1(permd);
h=figure; 
b=bar(OR2'); 
xticklabels(ORnames); 
ylim([0 12]); yticks(0:11);
yline(1,'Color','k','LineWidth',1.5);
%title('MNP2');
set(gca,'TickLabelInterpreter','latex','Fontsize',14);
legend(barnames(selectK),'Fontsize',10); 
ylabel('odds ratio','Fontsize',12);
b(1).FaceColor = [1 1 1];
b(2).FaceColor = [0.8 0.8 0.8];
b(3).FaceColor = [0.4 0.4 0.4];
b(4).FaceColor = [0 0 0];
set(h, 'Position', [20 60 1400 300]);
%
%set(h, 'Position', [20 60 1100 300]);
name = 'OR1mnp2';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
% -------------------------------------------------------------------------