% -------------------------------------------------------------------------
clear; close all;
fn = 'Results\';
% -------------------------------------------------------------------------
% get dgp parameter
rng(12345);
[alphadgp,betadgp] = generate_data(4000);
thetadgp           = [alphadgp';betadgp];
[K,J]              = size(betadgp);
nSamples           = 10000;
% -------------------------------------------------------------------------
nsett   = 4;
models  = [1 1;1 0;0 1;0 0];
nmodels = size(models,1);
MSE     = zeros(nsett,nmodels);
IQR     = zeros(nsett,nmodels);
% table
for sett=1:nsett
    for m=1:nmodels
        sname            = ['SimulC' strrep(num2str(models(m,:)),' ','')...
                            'sett' num2str(sett) 'seed1.mat'];
        MNLme            = load([fn sname],'alphGibbs','betaGibbs');
        theta            = zeros(K+1,J-1,nSamples);
        theta(1,:,:)     = MNLme.alphGibbs;
        theta(2:end,:,:) = MNLme.betaGibbs;
        errors           = mean(theta,3)-thetadgp(:,2:end);
        MSE(sett,m)      = mean(errors(:).^2);
        srtth            = sort(theta,3);
        iqr      = srtth(:,:,0.75*nSamples,1)-srtth(:,:,0.25*nSamples+1,1);
        IQR(sett,m)      = mean(mean(iqr));
    end
end
% -------------------------------------------------------------------------
% figure 
MNL1 = load([fn 'SimulC11sett1seed1.mat'],'pc','pd','Cnum','Dnum'); 
MNL2 = load([fn 'SimulC11sett2seed1.mat'],'pc','pd','Cnum','Dnum'); 
MNL3 = load([fn 'SimulC11sett3seed1.mat'],'pc','pd','Cnum','Dnum'); 
MNL4 = load([fn 'SimulC11sett4seed1.mat'],'pc','pd','Cnum','Dnum'); 
Lc   = length(MNL1.pc);
Ld   = length(MNL1.pd);
% -------------------------------------------------------------------------
% distribution number of clusters
pc_hat1 = zeros(Lc,1);
pc_hat2 = zeros(Lc,1);
pc_hat3 = zeros(Lc,1);
pc_hat4 = zeros(Lc,1);
for l=1:Lc
    pc_hat1(l) = mean(MNL1.Cnum==l);
    pc_hat2(l) = mean(MNL2.Cnum==l);
    pc_hat3(l) = mean(MNL3.Cnum==l);
    pc_hat4(l) = mean(MNL4.Cnum==l);    
end
pd_hat1 = zeros(Ld,1);
pd_hat2 = zeros(Ld,1);
pd_hat3 = zeros(Ld,1);
pd_hat4 = zeros(Ld,1);
for l=1:Ld
    pd_hat1(l) = mean(MNL1.Dnum==l);
    pd_hat2(l) = mean(MNL2.Dnum==l);
    pd_hat3(l) = mean(MNL3.Dnum==l);
    pd_hat4(l) = mean(MNL4.Dnum==l);    
end
% -------------------------------------------------------------------------
% Figure: experiment 1 and 2
h=figure;
lw = 1.5;
subplot(1,2,1); % cluster J
plot(1:Lc,100*MNL1.pc','-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Lc,100*MNL2.pc(1:Lc)',':','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat1,'k-','LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat2,'k:','LineWidth',lw); 
xlim([1 Lc]); ylim([0 100]);
xlabel('number of clusters');
ylabel('probability');
title('outcome categories');
subplot(1,2,2); % cluster K
plot(1:Ld,100*MNL1.pd','-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Ld,100*MNL2.pd',':','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat1,'k-','LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat2,'k:','LineWidth',lw); 
xlim([1 Ld]); ylim([0 100]);
xlabel('number of clusters');
ylabel('probability');
title('explanatory categories');
legend('Experiment 1 prior','Experiment 2 prior','Experiment 1 posterior','Experiment 2 posterior');
set(h,'Position',[20 60 800 300]);
name = 'Simul12numClusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% Figure: experiment 3 and 4
h=figure;
subplot(1,2,1); % cluster J
plot(1:Lc,100*MNL3.pc','-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
%plot(1:Lc,100*MNL2.pc(1:Lc)',':','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat3,'k-','LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat4,'k:','LineWidth',lw); 
xlim([1 Lc]); ylim([0 100]);
xlabel('number of clusters');
ylabel('probability');
title('outcome categories');
subplot(1,2,2); % cluster K
plot(1:Ld,100*MNL3.pd','-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
%plot(1:Lc,100*MNL2.pd',':','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat3,'k-','LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat4,'k:','LineWidth',lw); 
xlim([1 Ld]); ylim([0 100]);
xlabel('number of clusters');
ylabel('probability');
title('explanatory categories');
legend('Experiment 3 and 4 prior','Experiment 3 posterior','Experiment 4 posterior');
set(h,'Position',[20 60 800 300]);
name = 'Simul34numClusters';
print(h,'-depsc2',[fn 'Figures/' name '.eps']);
print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------