% -------------------------------------------------------------------------
% Script HDMCM
% -------------------------------------------------------------------------
clear;
% settings
application  = 'Simul'; %'App'; 
cluster      = 'Both' ; % 'J'; 'K'; 'None'; 
seeds        = 1;
setting      = 1; %2;3;4
rng(12345);
% -------------------------------------------------------------------------
switch application
    case 'App'
        [Y,kappa,X,Xw,Xd,Yout,Xout] = app_data();
        Xw = Xw(:,[1 3:10]); X=X(:,[1 3:20]);  Xout=Xout(:,[1 3:20]);
        Lc             = 25;
        modeLc         = 15;
        priorc.eta2    = 20;
        Ld             = size(Xd,2)+1;
        modeLd         = 5;
        priord.eta2    = 1;
        v              = 1;
    case 'Simul'
        Lc             = 25;
        priorc.eta2    = 20;
        priord.eta2    = 1;
        switch setting
            case 1
                modeLc         = 15;
                modeLd         = 5;
                v              = 1;
                N              = 4000;
            case 2
                modeLc         = 20;
                modeLd         = 8;
                v              = 1;
                N              = 4000;
            case 3
                modeLc         = 15;
                modeLd         = 5;
                v              = 2;
                N              = 4000;
            case 4
                modeLc         = 15;
                modeLd         = 5;
                v              = 1;
                N              = 400;
        end
        [alphadgp,betadgp,betamle,betabin,Xw,Xd,X,Y,kappa,Yout,Xout,prob] =...
            generate_data(N);
        Ld             = size(Xd,2)+1;
end
% -------------------------------------------------------------------------
switch cluster
    case 'Both'
        clusterJK    = [1;1];
    case 'J'
        clusterJK    = [1;0];
    case 'K'
        clusterJK    = [0;1];
    case 'None'
        clusterJK    = [0;0];
end
% -------------------------------------------------------------------------
namescript = [application 'C' strrep(num2str(clusterJK'),' ','') ...
    'sett' num2str(setting) 'seed' num2str(seeds)];
disp(namescript);
% -------------------------------------------------------------------------
% data dimensions
[N,J] = size(Y);
Kw    = size(Xw,2);
Kd    = size(Xd,2);
K     = Kw+Kd;
% -------------------------------------------------------------------------
% SET DPM PRIORS
% priors C
if clusterJK(1)==1
    lambdac        = smoothparam(modeLc,J-1);
    priorc.eta1    = lambdac*priorc.eta2;
    [Ec,Vc,pc]     = alpha2num(priorc,J,Lc,10000);
    [lambdac,Pc,C] = priordraw(priorc,J-1,Lc); 
    figure; bar(pc);
else
    pc      = 1;
    Lc      = J;
    C       = (2:J)';
    lambdac = 1;
end
% priors D
if clusterJK(2)==1
    lambdad        = smoothparam(modeLd,Kd);
    priord.eta1    = lambdad*priord.eta2;
    [Ed,Vd,pd]     = alpha2num(priord,Kd+1,Ld,10000);
    [lambdad,Pd,D] = priordraw(priord,Kd,Ld);
    figure; bar(pd);
else
    pd      = 1;
    Ld      = Kd+1;
    lambdad = 1;
    D       = (2:Kd+1)';
end
wD            = [(1:Kw) (Kw+D')];
Dold          = D;
% -------------------------------------------------------------------------
% initialize sampler
beta         = [zeros(K,1) zeros(K,J-1)];
alpha        = log(sum(Y)'/sum(Y(:,1)));
axb          = X*beta+alpha';
eaxb         = exp(axb);
seaxb        = sum(eaxb,2);
Xlint        = Xw;
Xld          = Xd;
[Xcluster,indexb] = clusterX(Xld,D,Ld);
Xl           =  [Xlint Xcluster];
% -------------------------------------------------------------------------
% sampler
burnin       = 500000;
nSamples     = 10000;
thin         = 50;
nGibbs       = burnin+nSamples*thin;
saveIndex    = 0;
betaGibbs    = zeros(K,J-1,nSamples);
betLGibbs    = zeros(Kw+Ld,Lc,nSamples);
alphGibbs    = zeros(J-1,nSamples);
cindGibbs    = zeros(J-1,nSamples);
dindGibbs    = zeros(Kd,nSamples);
lamcGibbs    = zeros(1,nSamples);
lamdGibbs    = zeros(1,nSamples);
startGibbs   = tic;
rng(seeds);
for g=1:nGibbs
    % ---------------------------------------------------------------------
    if  sum(Dold~=D)>0 && clusterJK(2)==1
        [Xcluster,indexb] = clusterX(Xld,D,Ld);
        Xl                = [Xlint Xcluster]; 
    end
    Dold = D;
    % ---------------------------------------------------------------------
    % sample coefficients beta
    indexbw        = [ones(Kw,1);indexb];
    [alpha,betacd] = MNLpgNEW(Y,indexbw,X,Xl,alpha,beta,v,C,wD,Lc); 
    % ---------------------------------------------------------------------
    if clusterJK(1) ==1
        % calculate loglik each cat j for each cluster l
        beta   = betacd(wD,[1;C]);
        betaLc = betacd(wD,:);
        Fc     = MNLllc(Y,X,alpha,beta,betaLc);
        % sample cluster indicators Y categories
        [C,Pc,~,lambdac] = sampleInd(Fc,Pc,lambdac,priorc);
    end
    % ---------------------------------------------------------------------
    if clusterJK(2)==1
        % calculate loglik each cat k for each cluster l
        beta   = betacd(wD,[1;C]);
        betaLd = betacd(Kw+1:end,[1;C]);
        Fd     = MNLlld(Y,X,alpha,beta,betaLd,Kw);
        % sample cluster indicators X categories
        [D,Pd,~,lambdad] = sampleInd(Fd,Pd,lambdad,priord);
        wD               = [(1:Kw) (Kw+D')];
    end
    % ---------------------------------------------------------------------
    beta             = betacd(wD,[1;C]);
    % ---------------------------------------------------------------------
    % save results after burnin
    if g>burnin && mod(g,thin)==0
        saveIndex                = saveIndex+1;
        betaGibbs(:,:,saveIndex) = beta(:,2:end);
        betLGibbs(:,:,saveIndex) = betacd;
        alphGibbs(:,saveIndex)   = alpha(2:end);
        cindGibbs(:,saveIndex)   = C;
        dindGibbs(:,saveIndex)   = D;
        lamcGibbs(:,saveIndex)   = lambdac;
        lamdGibbs(:,saveIndex)   = lambdad;
    end
    % ---------------------------------------------------------------------
    % display progress
    if mod(g,1000)==0
        disp([num2str(g) ' iterations of a total of ' num2str(nGibbs)...
            ' iterations in ' num2str(toc(startGibbs)) ' seconds.']);
        %disp(alpha(1:10)');
    end
    % ---------------------------------------------------------------------
end
timeGibbs = toc(startGibbs);
% -------------------------------------------------------------------------
% posterior distribution number of clusters
Cnum = zeros(nSamples,1);
Dnum = zeros(nSamples,1);
for g=1:nSamples
    Cnum(g) = length(unique([1;cindGibbs(:,g)]));
    Dnum(g) = length(unique([1;dindGibbs(:,g)]));
end
% -------------------------------------------------------------------------
%performance
Ycatin      = J+1-sum(cumsum(Y,2),2);
hrin_n = mean(Ycatin==mode(Ycatin));
probn = mean(Y);
lsin_n  = sum(sum(Y.*log(probn),2))/N;

Ycatout = J+1-sum(cumsum(Yout,2),2);
hrout_n = mean(Ycatout==mode(Ycatin));
lsout_n  = sum(sum(Yout.*log(probn),2))/size(Yout,1);

%rng(setseed,'twister');
startIn = tic;
[hrin,lsin,Ypredin,probin] = statPredictive(Y,X,alphGibbs,betaGibbs);
timeIn = toc(startIn);

startOut = tic;
[hrout,lsout,Ypredout,probout] = statPredictive(Yout,Xout,alphGibbs,betaGibbs);
timeOut = toc(startOut);
[[hrin hrin_n];[hrout hrout_n];[lsin lsin_n];[lsout lsout_n]]
% -------------------------------------------------------------------------
% convergence
[K,Jm1,nSamples] = size(betaGibbs);
theta            = [alphGibbs;reshape(betaGibbs,K*Jm1,nSamples)]';
[~,~,cd_theta,if_theta] = statsConvergence(theta,Jm1+1,K+1);
% -------------------------------------------------------------------------
% calculate probabilities 
prob = zeros(nSamples,J,Kd+1);
CD   = zeros(J,Kd+1);
IF   = zeros(J,Kd+1);
% figure; 
for k = 1:Kd+1
    Xe = zeros(1,K); 
    if k<Kd+1
    Xe(Kw+k)=1;
    end
    for g = 1:nSamples
        expXB       = [1 exp(alphGibbs(:,g)'+Xe*betaGibbs(:,:,g))];
        probig      = expXB/sum(expXB);
        prob(g,:,k)   = probig;
    end
    [~,~,cdp,ifp] = statsConvergence(prob(:,:,k),J+1,1);
    CD(:,k)       = cdp(:,1);
    IF(:,k)       = ifp;
end
% -------------------------------------------------------------------------
save(namescript,'-v7.3','betaGibbs','alphGibbs','cindGibbs','dindGibbs',...
    'hrin','lsin','hrout','lsout','probin','probout','Y','Yout',...
    'pc','pd','Cnum','Dnum','lamcGibbs','lamdGibbs','X','Xout',...
    'cd_theta','if_theta','prob','CD','IF','timeGibbs');
% -------------------------------------------------------------------------