clear;
load('Mixed.mat') %-> results MNLmixed
% -------------------------------------------------------------------------
% convergence
[Jm1,K,nSamples] = size(bsave);
theta            = [asave;reshape(bsave,K*Jm1,nSamples);qsave;reshape(Qsave,Jm1^2,nSamples)]';
[~,~,cd_theta,if_theta] = statsConvergence(theta,Jm1+1,K+1+1+Jm1);
% include in paper:
[mean(cd_theta) nanmedian(if_theta) max(if_theta)]
% -------------------------------------------------------------------------
% number unique parameter values
% -------------------------------------------------------------------------
% posterior distribution number of clusters
Cnum = zeros(nSamples,1);
Dnum = zeros(nSamples,1);
for g=1:nSamples
    Cnum(g) = length(unique([1;Csave(:,g)]));
    Dnum(g) = length(unique([1;Dsave(:,g)]));
end

% distribution number of clusters
[Ec,Vc,pc]    = alpha2num(priorc,J,Lc,10000);
[Ed,Vd,pd]    = alpha2num(priord,Kd+1,Ld,10000);
pc_hat2 = zeros(Lc,1);
pc_hatJ = zeros(Lc,1);
for l=1:Lc
    pc_hat2(l) = mean(Cnum==l);
end
pd_hat2 = zeros(Ld,1);
pd_hatK = zeros(Ld,1);
for l=1:Ld
    pd_hat2(l) = mean(Dnum==l);
end
% Figure: distribution number of unique parameters
h=figure;
lw = 2;
subplot(1,2,1); % cluster J
plot(1:Lc,100*pc,'-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Lc,100*pc_hat2,'k-','LineWidth',lw); hold on;
xlim([1 Lc]);
xlabel('number of clusters');
ylabel('probability');
title('outcome categories');
subplot(1,2,2); % cluster K
plot(1:Ld,100*pd,'-','Color',[0.6 .6 .6],'LineWidth',lw); hold on;
plot(1:Ld,100*pd_hat2,'k-','LineWidth',lw); hold on;
xlim([1 Ld]);
% set(gca,'XTick', 1:1:d1,'YTick',0.1:0.1:1.0,'FontSize',fs);
xlabel('number of clusters');
ylabel('probability');
title('explanatory categories');
legend('prior','two-way');
set(h,'Position',[20 60 800 300]);
name = 'MixednumClusters';
print(h,'-depsc2',['Figures/' name '.eps']);
% print(h,'-djpeg',[fn 'Figures/' name '.jpg']);
% -------------------------------------------------------------------------
% parameters

h=figure;
t = tiledlayout(2,2,'TileSpacing','compact','Padding','compact');
% A = [zeros(1,K);betamle'];
% scatter(betadgp(:),A(:),'r.'); hold on;
nexttile%subplot(3,2,1);
A = mean(asave,2);
B = alphadgp(2:end);
scatter(B(:),A(:),10,'k'); hold on;
lim1 = [-1.2 1.2];
plot(lim1,lim1','k'); 
xlim(lim1); ylim(lim1);
xticks([-1 -0.5 0 0.5 1]);yticks([-1 -0.5 0 0.5 1]);
title('Intercepts $\alpha$','Interpreter','latex');
xlabel('DGP value','Interpreter','latex'); 
ylabel('Posterior mean','Interpreter','latex');
axis square; box on;
%
nexttile%subplot(3,2,2);
bmean = mean(bsave,3);
bdgp = betadgp(:,2:end)';
scatter(bdgp(:),bmean(:),10,'k'); hold on;
lim1 = [-3 3];
plot(lim1,lim1','k'); 
xlim(lim1); ylim(lim1);
xticks([-2 -1 0 1 2]);yticks([-2 -1 0 1 2]);
title('Coefficients $\beta$','Interpreter','latex');
xlabel('DGP value','Interpreter','latex'); 
ylabel('Posterior mean','Interpreter','latex');
axis square; box on;
%
nexttile%subplot(3,2,3);
qmean = mean(qsave,2);
scatter(qdgp,qmean,10,'k'); hold on;
lim1 = [-3 3];
plot(lim1,lim1','k'); 
xlim(lim1); ylim(lim1);
xticks([-2 -1 0 1 2]);yticks([-2 -1 0 1 2]);
title('Mean vector $u$','Interpreter','latex');
xlabel('DGP value','Interpreter','latex'); 
ylabel('Posterior mean','Interpreter','latex');
axis square; box on;
%
nexttile%figure;
Qmean = mean(Qsave,3);
scatter(Qdgp(:),Qmean(:),10,'k'); hold on;
lim1 = [-.5 2];
plot(lim1,lim1','k'); 
xlim(lim1); ylim(lim1);
xticks([0 1 2]);yticks([0 1 2]);
title('Covariance matrix $Q$','Interpreter','latex');
xlabel('DGP value','Interpreter','latex'); 
ylabel('Posterior mean','Interpreter','latex');
axis square; box on;
%
set(h,'Position',[20 60 700 700]);
name = 'Mixedparam';
print(h,'-depsc2',['Figures/' name '.eps']);

h2=figure;
%nexttile([1 2]); %subplot(3,2,[5 6]); 
nmean = mean(nsave,3);
ndgp =nudgp(1:N,2:end);
scatter(ndgp(:),nmean(:),10,'k'); hold on;
lim1 = [-7 7];
plot(lim1,lim1','k'); 
xlim(lim1); ylim(lim1);
xticks([-6:1:6]);yticks([-6:2:6]);
title('Random coefficients $\nu$','Interpreter','latex');
xlabel('DGP value','Interpreter','latex'); 
ylabel('Posterior mean','Interpreter','latex'); 
box on;
%
set(h2,'Position',[20 60 700 800/3]);
name = 'Mixedparam2';
print(h2,'-depsc2',['Figures/' name '.eps']);
% -------------------------------------------------------------------------