% -------------------------------------------------------------------------
% function that constructs X from clustered dummies
% note that we have category specific intercept.
% so we can only include K-1 dummies
% and dummies should be able have same effect as intercept: coef=0.
% -------------------------------------------------------------------------
function [Xl,indexwd,Xind] = clusterX(Xw,Xcats,D,L)
% -------------------------------------------------------------------------
% L = number of clusters
% D is K*1 classification vector, with K is number of categories
% do not include categories with D=1 in Xcluster - same effect as intercept
% -------------------------------------------------------------------------
[N,Kd]    = size(Xcats);
Kw        = size(Xw,2);
Xcluster  = zeros(N,L);
Xind      = zeros(Kd,L);
indexd    = zeros(L,1);
indexd(1) = -1;
for l=2:L
    indexl = D==l;
    numl   = sum(indexl);
    if numl>0
        Xcluster(:,l) = sum(Xcats(:,indexl),2);
        Xind(:,l)     = indexl;
        indexd(l,1)   = 1;
    end
end
Xcluster(:,indexd~=1) = [];
Xind(:,indexd~=1)     = [];
Xl                    = [Xw Xcluster];
Xind                  = blkdiag(eye(Kw),Xind);
indexwd               = [ones(Kw,1); indexd];
% -------------------------------------------------------------------------
end