function [CDstat, IFstat, CD, IF] = statsConvergence(beta,J,K) 
% -------------------------------------------------------------------------
% convergence statistics for beta nSamples*nParams
% CD: [T reject 10%, reject 5%, reject 1%];
% -------------------------------------------------------------------------
[nSamples,nParams] = size(beta);
CD    = zeros(nParams,4);
IF    = zeros(nParams,1);
bw    = 0.04*nSamples;     %bandwith 0.04
w     = 1-(1:bw)'/(bw+1);  %bartlett kernel
for k=1:nParams
    % Geweke convergence test
    betak   = beta(:,k);
    if sum(betak==0)<length(betak)
    n1      = nSamples*0.2;
    n2      = nSamples*0.4;
    sample1 = betak(1:n1,1);
    sample2 = betak(end-n2+1:end,1);
    rho1    = autocorr(sample1,bw);
    rho1    = var(sample1)*rho1(2:end,1);
    rho2    = autocorr(sample2,bw);
    rho2    = var(sample2)*rho2(2:end,1);
    s1      = var(sample1)+2*sum(w.*rho1);
    s2      = var(sample2)+2*sum(w.*rho2);
    T       = (mean(sample1)-mean(sample2))/sqrt(s1/n1 + s2/n2);
    nu      = ((s1/n1 + s2/n2)^2)/(((s1/n1)^2)/(n1-1)+((s2/n2)^2)/(n2-1));
    c10     =  tinv(1-0.10/2,nu);
    c5      =  tinv(1-0.05/2,nu);
    c1      =  tinv(1-0.01/2,nu);
    CD(k,:) = [T abs(T)>c10 abs(T)>c5 abs(T)>c1];
    end
    % Inefficiency factors
    rho     = autocorr(betak,bw);
    rho     = rho(2:end,1);
    IF(k,1) = 1+2*sum(w.*rho); %of plus 2*sum? vraag bart!
end
% -------------------------------------------------------------------------
IFj      = reshape(IF',K,J-1)';  
%IFj(sum(isnan(IFj),2)>0,:)=[];
IFstat   = [nanmean(IFj)' nanmin(IFj)' nanmax(IFj)' ];
CDstat   = [mean(reshape(CD(:,2)',K,J-1)')' mean(reshape(CD(:,3)',K,J-1)')' mean(reshape(CD(:,4)',K,J-1)')'] ;
% -------------------------------------------------------------------------
end
